@@ -42,21 +42,7 @@ bool DBin::checkParameterValue (vector<double const *> const &par) const
 double DBin::d(double x, PDFType type, vector<double const *> const &par, 
 	       bool give_log) const
 {
-    if (type == PDF_LIKELIHOOD) {
-	//Avoid expensive call to lchoose
-	double p = PROB(par), n = SIZE(par);
-	if (x < 0 || x > n || (p == 0 && x != 0) || (p == 1 && x != n))
-	    return give_log ? JAGS_NEGINF : 0;
-	double y = 0;
-	if (p != 0)
-	    y +=  x * log(p);
-	if (p != 1)
-	    y += (n - x) * log(1 - p);
-	return give_log ? y : exp(y);
-    }
-    else {
-	return dbinom(x, SIZE(par), PROB(par), give_log);
-    }
+    return dbinom(x, SIZE(par), PROB(par), give_log);
 }
 
 double DBin::p(double x, vector<double const *> const &par, 
