@@ -3,6 +3,8 @@
 
 #include "ConjugateMethod.h"
 
+namespace bugs {
+
 /**
  * @short Conjugate sampler for Dirichlet distribution.  
  *
@@ -24,4 +26,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* CONJUGATE_DIRICHLET_H_ */
